Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterExpansion
- type ClusterInterface
- type ClustersGetter
- type InstanceGroupExpansion
- type InstanceGroupInterface
- type InstanceGroupsGetter
- type KeysetExpansion
- type KeysetInterface
- type KeysetsGetter
- type KopsClient
- func (c *KopsClient) Clusters(namespace string) ClusterInterface
- func (c *KopsClient) InstanceGroups(namespace string) InstanceGroupInterface
- func (c *KopsClient) Keysets(namespace string) KeysetInterface
- func (c *KopsClient) RESTClient() rest.Interface
- func (c *KopsClient) SSHCredentials(namespace string) SSHCredentialInterface
- type KopsInterface
- type SSHCredentialExpansion
- type SSHCredentialInterface
- type SSHCredentialsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterExpansion ¶
type ClusterExpansion interface{}
type ClusterInterface ¶
type ClusterInterface interface {
Create(*kops.Cluster) (*kops.Cluster, error)
Update(*kops.Cluster) (*kops.Cluster, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*kops.Cluster, error)
List(opts v1.ListOptions) (*kops.ClusterList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *kops.Cluster, err error)
ClusterExpansion
}
ClusterInterface has methods to work with Cluster resources.
type ClustersGetter ¶
type ClustersGetter interface {
Clusters(namespace string) ClusterInterface
}
ClustersGetter has a method to return a ClusterInterface. A group's client should implement this interface.
type InstanceGroupExpansion ¶
type InstanceGroupExpansion interface{}
type InstanceGroupInterface ¶
type InstanceGroupInterface interface {
Create(*kops.InstanceGroup) (*kops.InstanceGroup, error)
Update(*kops.InstanceGroup) (*kops.InstanceGroup, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*kops.InstanceGroup, error)
List(opts v1.ListOptions) (*kops.InstanceGroupList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *kops.InstanceGroup, err error)
InstanceGroupExpansion
}
InstanceGroupInterface has methods to work with InstanceGroup resources.
type InstanceGroupsGetter ¶
type InstanceGroupsGetter interface {
InstanceGroups(namespace string) InstanceGroupInterface
}
InstanceGroupsGetter has a method to return a InstanceGroupInterface. A group's client should implement this interface.
type KeysetExpansion ¶
type KeysetExpansion interface{}
type KeysetInterface ¶
type KeysetInterface interface {
Create(*kops.Keyset) (*kops.Keyset, error)
Update(*kops.Keyset) (*kops.Keyset, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*kops.Keyset, error)
List(opts v1.ListOptions) (*kops.KeysetList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *kops.Keyset, err error)
KeysetExpansion
}
KeysetInterface has methods to work with Keyset resources.
type KeysetsGetter ¶
type KeysetsGetter interface {
Keysets(namespace string) KeysetInterface
}
KeysetsGetter has a method to return a KeysetInterface. A group's client should implement this interface.
type KopsClient ¶
type KopsClient struct {
// contains filtered or unexported fields
}
KopsClient is used to interact with features provided by the kops group.
func New ¶
func New(c rest.Interface) *KopsClient
New creates a new KopsClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*KopsClient, error)
NewForConfig creates a new KopsClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *KopsClient
NewForConfigOrDie creates a new KopsClient for the given config and panics if there is an error in the config.
func (*KopsClient) Clusters ¶
func (c *KopsClient) Clusters(namespace string) ClusterInterface
func (*KopsClient) InstanceGroups ¶
func (c *KopsClient) InstanceGroups(namespace string) InstanceGroupInterface
func (*KopsClient) Keysets ¶
func (c *KopsClient) Keysets(namespace string) KeysetInterface
func (*KopsClient) RESTClient ¶
func (c *KopsClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*KopsClient) SSHCredentials ¶
func (c *KopsClient) SSHCredentials(namespace string) SSHCredentialInterface
type KopsInterface ¶
type KopsInterface interface {
RESTClient() rest.Interface
ClustersGetter
InstanceGroupsGetter
KeysetsGetter
SSHCredentialsGetter
}
type SSHCredentialExpansion ¶
type SSHCredentialExpansion interface{}
type SSHCredentialInterface ¶
type SSHCredentialInterface interface {
Create(*kops.SSHCredential) (*kops.SSHCredential, error)
Update(*kops.SSHCredential) (*kops.SSHCredential, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*kops.SSHCredential, error)
List(opts v1.ListOptions) (*kops.SSHCredentialList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *kops.SSHCredential, err error)
SSHCredentialExpansion
}
SSHCredentialInterface has methods to work with SSHCredential resources.
type SSHCredentialsGetter ¶
type SSHCredentialsGetter interface {
SSHCredentials(namespace string) SSHCredentialInterface
}
SSHCredentialsGetter has a method to return a SSHCredentialInterface. A group's client should implement this interface.