Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterExpansion ¶
type ClusterExpansion interface{}
type ClusterInterface ¶
type ClusterInterface interface {
Create(*v1alpha1.Cluster) (*v1alpha1.Cluster, error)
Update(*v1alpha1.Cluster) (*v1alpha1.Cluster, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Cluster, error)
List(opts v1.ListOptions) (*v1alpha1.ClusterList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Cluster, err error)
ClusterExpansion
}
ClusterInterface has methods to work with Cluster resources.
type ClustersGetter ¶
type ClustersGetter interface {
Clusters(namespace string) ClusterInterface
}
ClustersGetter has a method to return a ClusterInterface. A group's client should implement this interface.
type InstanceGroupExpansion ¶
type InstanceGroupExpansion interface{}
type InstanceGroupInterface ¶
type InstanceGroupInterface interface {
Create(*v1alpha1.InstanceGroup) (*v1alpha1.InstanceGroup, error)
Update(*v1alpha1.InstanceGroup) (*v1alpha1.InstanceGroup, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.InstanceGroup, error)
List(opts v1.ListOptions) (*v1alpha1.InstanceGroupList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.InstanceGroup, err error)
InstanceGroupExpansion
}
InstanceGroupInterface has methods to work with InstanceGroup resources.
type InstanceGroupsGetter ¶
type InstanceGroupsGetter interface {
InstanceGroups(namespace string) InstanceGroupInterface
}
InstanceGroupsGetter has a method to return a InstanceGroupInterface. A group's client should implement this interface.
type KopsV1alpha1Client ¶
type KopsV1alpha1Client struct {
// contains filtered or unexported fields
}
KopsV1alpha1Client is used to interact with features provided by the kops group.
func New ¶
func New(c rest.Interface) *KopsV1alpha1Client
New creates a new KopsV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*KopsV1alpha1Client, error)
NewForConfig creates a new KopsV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *KopsV1alpha1Client
NewForConfigOrDie creates a new KopsV1alpha1Client for the given config and panics if there is an error in the config.
func (*KopsV1alpha1Client) Clusters ¶
func (c *KopsV1alpha1Client) Clusters(namespace string) ClusterInterface
func (*KopsV1alpha1Client) InstanceGroups ¶
func (c *KopsV1alpha1Client) InstanceGroups(namespace string) InstanceGroupInterface
func (*KopsV1alpha1Client) RESTClient ¶
func (c *KopsV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*KopsV1alpha1Client) SSHCredentials ¶
func (c *KopsV1alpha1Client) SSHCredentials(namespace string) SSHCredentialInterface
type KopsV1alpha1Interface ¶
type KopsV1alpha1Interface interface {
RESTClient() rest.Interface
ClustersGetter
InstanceGroupsGetter
SSHCredentialsGetter
}
type SSHCredentialExpansion ¶
type SSHCredentialExpansion interface{}
type SSHCredentialInterface ¶
type SSHCredentialInterface interface {
Create(*v1alpha1.SSHCredential) (*v1alpha1.SSHCredential, error)
Update(*v1alpha1.SSHCredential) (*v1alpha1.SSHCredential, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.SSHCredential, error)
List(opts v1.ListOptions) (*v1alpha1.SSHCredentialList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.SSHCredential, err error)
SSHCredentialExpansion
}
SSHCredentialInterface has methods to work with SSHCredential resources.
type SSHCredentialsGetter ¶
type SSHCredentialsGetter interface {
SSHCredentials(namespace string) SSHCredentialInterface
}
SSHCredentialsGetter has a method to return a SSHCredentialInterface. A group's client should implement this interface.